/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import { RouteRecordRaw } from 'vue-router'
import pageView from '@/layouts/index.vue'

const routes: RouteRecordRaw[] = [
  {
    path: '/user',
    redirect: '/user/profile',
    component: pageView,
    meta: {
      hidden: true
    },
    children: [
      {
        path: 'profile',
        component: () => import('@/pages/user/profile/index.vue'),
        meta: {
          title: 'Profile',
          activeMenu: ''
        }
      },
      {
        path: 'settings',
        component: () => import('@/pages/user/settings/index.vue'),
        meta: {
          title: 'Settings',
          activeMenu: ''
        }
      }
    ]
  }
]

export { routes }
